@@ -43,17 +43,15 @@ def test_target_validation_raises(poisson, invalid_target):
     ],
 )
 def test_gradient_calculation(poisson, y, params, natural_gradient, expected_grad):
-    grad, hess = poisson.gradient_and_hessian(
-        y, params, natural_gradient=natural_gradient
-    )
+    grad, _ = poisson.gradient_and_hessian(y, params, natural_gradient=natural_gradient)
     np.testing.assert_array_equal(grad, expected_grad)
 
 
 def test_loss(poisson):
-    loss_name, loss_value = poisson.loss(
+    loss_name, loss_values = poisson.loss(
         # fmt: off
         y=np.array([1, ]),
-        params=np.array([[np.log(1)], ]),
+        params=np.array([np.log(1), ]),
     )
     assert loss_name == "Poisson-NLL"
-    assert loss_value == 1.0
+    np.testing.assert_array_equal(loss_values, np.array([1.0]))
